@@ -6,7 +6,7 @@ import math
 import multiprocessing as mp
 import itertools
 import pandas as pd
-import .utils as utils
+import utils as utils
 import gc
 from tqdm import tqdm
 
